@@ -70,7 +70,7 @@ def float_range(start: float, stop: float, step: float = 1.0, decimals: int = 2)
 
 
 def retry(times: int, exception_class: Type = BaseException, sleep=0):
-    assert times >= 1, "times should be >= in @retry"
+    require(times >= 1, "times should be >= in @retry")
 
     def decorated(func):
         @wraps(func)
@@ -81,12 +81,21 @@ def retry(times: int, exception_class: Type = BaseException, sleep=0):
                 try:
                     return func(*args, **kwargs)
                 except exception_class as exc:
+                    logger.warning(f'Execution of {func} failed (attempt: {attempt}/{times})')
                     attempt += 1
                     last_exception = exc
                     if attempt <= times:
+                        logger.debug(f'Will retry in {sleep} seconds')
                         time.sleep(sleep)
                     else:
                         raise exc
             raise last_exception
         return wrapper
     return decorated
+
+
+class IntSequence:
+    _last_id = 0
+    def create_new_id(self) -> int:
+        self._last_id += 1
+        return self._last_id
\ No newline at end of file
